==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterListenerMatchFluent<A extends EnvoyFilterListenerMatchFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterListenerMatchFluent() {
  }
  public EnvoyFilterListenerMatchFluent(EnvoyFilterListenerMatch instance) {
    instance = (instance != null ? instance : new EnvoyFilterListenerMatch());

    if (instance != null) {
      this.withFilterChain(instance.getFilterChain());
      this.withName(instance.getName());
      this.withPortName(instance.getPortName());
      this.withPortNumber(instance.getPortNumber());
      this.withFilterChain(instance.getFilterChain());
      this.withName(instance.getName());
      this.withPortName(instance.getPortName());
      this.withPortNumber(instance.getPortNumber());
    }
  }
  private EnvoyFilterListenerMatchFilterChainMatchBuilder filterChain;
  private String name;
  private String portName;
  private Integer portNumber;
  public EnvoyFilterListenerMatchFilterChainMatch buildFilterChain() {
    return this.filterChain!=null ?this.filterChain.build():null;
  }
  public A withFilterChain(EnvoyFilterListenerMatchFilterChainMatch filterChain) {
    _visitables.get("filterChain").remove(this.filterChain);
    if (filterChain!=null){ this.filterChain= new EnvoyFilterListenerMatchFilterChainMatchBuilder(filterChain); _visitables.get("filterChain").add(this.filterChain);} else { this.filterChain = null; _visitables.get("filterChain").remove(this.filterChain); } return (A) this;
  }
  public boolean hasFilterChain() {
    return this.filterChain != null;
  }
  public FilterChainNested<A> withNewFilterChain() {
    return new FilterChainNested(null);
  }
  public FilterChainNested<A> withNewFilterChainLike(EnvoyFilterListenerMatchFilterChainMatch item) {
    return new FilterChainNested(item);
  }
  public FilterChainNested<A> editFilterChain() {
    return withNewFilterChainLike(java.util.Optional.ofNullable(buildFilterChain()).orElse(null));
  }
  public FilterChainNested<A> editOrNewFilterChain() {
    return withNewFilterChainLike(java.util.Optional.ofNullable(buildFilterChain()).orElse(new EnvoyFilterListenerMatchFilterChainMatchBuilder().build()));
  }
  public FilterChainNested<A> editOrNewFilterChainLike(EnvoyFilterListenerMatchFilterChainMatch item) {
    return withNewFilterChainLike(java.util.Optional.ofNullable(buildFilterChain()).orElse(item));
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getPortName() {
    return this.portName;
  }
  public A withPortName(String portName) {
    this.portName=portName; return (A) this;
  }
  public boolean hasPortName() {
    return this.portName != null;
  }
  public Integer getPortNumber() {
    return this.portNumber;
  }
  public A withPortNumber(Integer portNumber) {
    this.portNumber=portNumber; return (A) this;
  }
  public boolean hasPortNumber() {
    return this.portNumber != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterListenerMatchFluent that = (EnvoyFilterListenerMatchFluent) o;
    if (!java.util.Objects.equals(filterChain, that.filterChain)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(portName, that.portName)) return false;

    if (!java.util.Objects.equals(portNumber, that.portNumber)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(filterChain,  name,  portName,  portNumber,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (filterChain != null) { sb.append("filterChain:"); sb.append(filterChain + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (portName != null) { sb.append("portName:"); sb.append(portName + ","); }
    if (portNumber != null) { sb.append("portNumber:"); sb.append(portNumber); }
    sb.append("}");
    return sb.toString();
  }
  public class FilterChainNested<N> extends EnvoyFilterListenerMatchFilterChainMatchFluent<FilterChainNested<N>> implements Nested<N>{
    FilterChainNested(EnvoyFilterListenerMatchFilterChainMatch item) {
      this.builder = new EnvoyFilterListenerMatchFilterChainMatchBuilder(this, item);
    }
    EnvoyFilterListenerMatchFilterChainMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterListenerMatchFluent.this.withFilterChain(builder.build());
    }
    public N endFilterChain() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class EnvoyFilterListenerMatchFluent<A extends EnvoyFilterListenerMatchFluent<A>> extends BaseFluent<A>{
  public EnvoyFilterListenerMatchFluent() {
  }
  
  public EnvoyFilterListenerMatchFluent(EnvoyFilterListenerMatch instance) {
    this.copyInstance(instance);
  }
  private EnvoyFilterListenerMatchFilterChainMatchBuilder filterChain;
  private String name;
  private String portName;
  private Integer portNumber;
  
  protected void copyInstance(EnvoyFilterListenerMatch instance) {
    instance = (instance != null ? instance : new EnvoyFilterListenerMatch());
  
    if (instance != null) {
        this.withFilterChain(instance.getFilterChain());
        this.withName(instance.getName());
        this.withPortName(instance.getPortName());
        this.withPortNumber(instance.getPortNumber());
        this.withFilterChain(instance.getFilterChain());
        this.withName(instance.getName());
        this.withPortName(instance.getPortName());
        this.withPortNumber(instance.getPortNumber());
      }
  }
  
  public EnvoyFilterListenerMatchFilterChainMatch buildFilterChain() {
    return this.filterChain!=null ?this.filterChain.build():null;
  }
  
  public A withFilterChain(EnvoyFilterListenerMatchFilterChainMatch filterChain) {
    _visitables.get("filterChain").remove(this.filterChain);
    if (filterChain!=null){ this.filterChain= new EnvoyFilterListenerMatchFilterChainMatchBuilder(filterChain); _visitables.get("filterChain").add(this.filterChain);} else { this.filterChain = null; _visitables.get("filterChain").remove(this.filterChain); } return (A) this;
  }
  
  public boolean hasFilterChain() {
    return this.filterChain != null;
  }
  
  public FilterChainNested<A> withNewFilterChain() {
    return new FilterChainNested(null);
  }
  
  public FilterChainNested<A> withNewFilterChainLike(EnvoyFilterListenerMatchFilterChainMatch item) {
    return new FilterChainNested(item);
  }
  
  public FilterChainNested<A> editFilterChain() {
    return withNewFilterChainLike(java.util.Optional.ofNullable(buildFilterChain()).orElse(null));
  }
  
  public FilterChainNested<A> editOrNewFilterChain() {
    return withNewFilterChainLike(java.util.Optional.ofNullable(buildFilterChain()).orElse(new EnvoyFilterListenerMatchFilterChainMatchBuilder().build()));
  }
  
  public FilterChainNested<A> editOrNewFilterChainLike(EnvoyFilterListenerMatchFilterChainMatch item) {
    return withNewFilterChainLike(java.util.Optional.ofNullable(buildFilterChain()).orElse(item));
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getPortName() {
    return this.portName;
  }
  
  public A withPortName(String portName) {
    this.portName=portName; return (A) this;
  }
  
  public boolean hasPortName() {
    return this.portName != null;
  }
  
  public Integer getPortNumber() {
    return this.portNumber;
  }
  
  public A withPortNumber(Integer portNumber) {
    this.portNumber=portNumber; return (A) this;
  }
  
  public boolean hasPortNumber() {
    return this.portNumber != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterListenerMatchFluent that = (EnvoyFilterListenerMatchFluent) o;
    if (!java.util.Objects.equals(filterChain, that.filterChain)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(portName, that.portName)) return false;
  
    if (!java.util.Objects.equals(portNumber, that.portNumber)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(filterChain,  name,  portName,  portNumber,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (filterChain != null) { sb.append("filterChain:"); sb.append(filterChain + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (portName != null) { sb.append("portName:"); sb.append(portName + ","); }
    if (portNumber != null) { sb.append("portNumber:"); sb.append(portNumber); }
    sb.append("}");
    return sb.toString();
  }
  public class FilterChainNested<N> extends EnvoyFilterListenerMatchFilterChainMatchFluent<FilterChainNested<N>> implements Nested<N>{
    FilterChainNested(EnvoyFilterListenerMatchFilterChainMatch item) {
      this.builder = new EnvoyFilterListenerMatchFilterChainMatchBuilder(this, item);
    }
    EnvoyFilterListenerMatchFilterChainMatchBuilder builder;
    
    public N and() {
      return (N) EnvoyFilterListenerMatchFluent.this.withFilterChain(builder.build());
    }
    
    public N endFilterChain() {
      return and();
    }
    
  
  }

}
